using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Filters;


namespace AcaMate.Common.Token;

public class APIHeaderFilter : ActionFilterAttribute
{
    private readonly string _headerName;

    public APIHeaderFilter(string headerName)
    {
        _headerName = headerName;
    }

    public override void OnActionExecuted(ActionExecutedContext context)
    {
        if (!context.HttpContext.Request.Headers.TryGetValue(_headerName, out var headerValues) ||
            string.IsNullOrWhiteSpace(headerValues))
        {
            context.Result = new BadRequestObjectResult($"Missing or empty header: {_headerName}");
        }
        
        base.OnActionExecuted(context);
    }
    
}